@@ -89,7 +89,14 @@ qsa_of_interest = ['acl', 'cors', 'defaultObjectAcl', 'location', 'logging',
                    # Storage.
                    'websiteConfig',
                    # compose is a QSA for objects in Google Cloud Storage.
-                   'compose']
+                   'compose',
+                   # billing is a QSA for buckets in Google Cloud Storage.
+                   'billing',
+                   # userProject is a QSA for requests in Google Cloud Storage.
+                   'userProject',
+                   # encryptionConfig is a QSA for requests in Google Cloud
+                   # Storage.
+                   'encryptionConfig']
 
 
 _first_cap_regex = re.compile('(.)([A-Z][a-z]+)')
@@ -220,10 +227,10 @@ def retry_url(url, retry_on_404=True, num_retries=10, timeout=None):
             if code == 404 and not retry_on_404:
                 return ''
         except Exception as e:
-            pass
-        boto.log.exception('Caught exception reading instance data')
+            boto.log.exception('Caught exception reading instance data')
         # If not on the last iteration of the loop then sleep.
         if i + 1 != num_retries:
+            boto.log.debug('Sleeping before retrying')
             time.sleep(min(2 ** i,
                            boto.config.get('Boto', 'max_retry_delay', 60)))
     boto.log.error('Unable to read instance data, giving up')
@@ -393,6 +400,8 @@ def get_instance_metadata(version='latest', url='http://169.254.169.254',
         metadata_url = _build_instance_metadata_url(url, version, data)
         return _get_instance_metadata(metadata_url, num_retries=num_retries, timeout=timeout)
     except urllib.error.URLError:
+        boto.log.exception("Exception caught when trying to retrieve "
+                           "instance metadata for: %s", data)
         return None
 
 
